@@ -845,11 +845,11 @@ bool KCupsConnection::retry(const char *resource, int operation) const
         // force authentication
         qCDebug(LIBKCUPS) << "Calling cupsDoAuthentication() password_retries:" << password_retries;
         int ret = cupsDoAuthentication(CUPS_HTTP_DEFAULT, "POST", resource);
-        qCDebug(LIBKCUPS) << "Called cupsDoAuthentication(), success:" << (ret == -1 ? true : false);
+        qCDebug(LIBKCUPS) << "Called cupsDoAuthentication(), success:" << (ret == 0);
 
         // If the authentication was successful
         // sometimes just trying to be root works
-        return ret == -1 ? true : false;
+        return ret == 0;
     }
 
     // the action was not forbidden
